from setuptools import setup
 
setup(
    name='tbsh',    # This is the name of your PyPI-package.
    version='0.1.8',                          # Update the version number for new releases    
    author="Sriharsha Sammeta",
    author_email="sriharsha4444@icloud.com",
    description='The funniest joke in the world',
    url='http://github.com/storborg/funniest',
    license='MIT',
    packages=['tbsh'],    
    zip_safe=False
)
